aboutsummaryrefslogtreecommitdiff
path: root/test/functional/vimscript/string_spec.lua
diff options
context:
space:
mode:
Diffstat (limited to 'test/functional/vimscript/string_spec.lua')
-rw-r--r--test/functional/vimscript/string_spec.lua8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/functional/vimscript/string_spec.lua b/test/functional/vimscript/string_spec.lua
index 32aa04c0d0..4df9104e1e 100644
--- a/test/functional/vimscript/string_spec.lua
+++ b/test/functional/vimscript/string_spec.lua
@@ -170,9 +170,9 @@ describe('string() function', function()
)
end)
- it('does not show errors when dumping partials referencing the same dictionary', function()
+ it('does not show errors when dumping partials referencing the same dict', function()
command('let d = {}')
- -- Regression for “eval/typval_encode: Dump empty dictionary before
+ -- Regression for “eval/typval_encode: Dump empty dict before
-- checking for refcycle”, results in error.
eq(
"[function('tr', {}), function('tr', {})]",
@@ -256,7 +256,7 @@ describe('string() function', function()
end)
describe('used to represent dictionaries', function()
- it('dumps empty dictionary', function()
+ it('dumps empty dict', function()
eq('{}', eval('string({})'))
end)
@@ -267,7 +267,7 @@ describe('string() function', function()
eq("[{}, function('tr', {})]", eval('string([d, function("tr", d)])'))
end)
- it('dumps non-empty dictionary', function()
+ it('dumps non-empty dict', function()
eq("{'t''est': 1}", fn.string({ ["t'est"] = 1 }))
end)